==> qtwebengine-everywhere-src-6.2.4.zip: qtwebengine-everywhere-src-6.2.4/src/3rdparty/chromium/chrome/browser/extensions/api/streams_private/streams_private_api.cc <==
// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "chrome/browser/extensions/api/streams_private/streams_private_api.h"

#include <utility>

#if !defined(TOOLKIT_QT)
#include "chrome/browser/extensions/extension_tab_util.h"
#include "chrome/browser/prefetch/no_state_prefetch/chrome_no_state_prefetch_contents_delegate.h"
#include "components/no_state_prefetch/browser/no_state_prefetch_contents.h"
#endif // !defined(TOOLKIT_QT)
#include "components/sessions/core/session_id.h"
#include "content/public/browser/browser_thread.h"
#include "content/public/browser/render_frame_host.h"
#include "content/public/browser/web_contents.h"
#include "extensions/browser/extension_registry.h"
#include "extensions/browser/guest_view/mime_handler_view/mime_handler_stream_manager.h"
#include "extensions/browser/guest_view/mime_handler_view/mime_handler_view_guest.h"
#include "extensions/common/manifest_handlers/mime_types_handler.h"

namespace extensions {

void StreamsPrivateAPI::SendExecuteMimeTypeHandlerEvent(
    const std::string& extension_id,
    const std::string& view_id,
    bool embedded,
    int frame_tree_node_id,
    int render_process_id,
    int render_frame_id,
    blink::mojom::TransferrableURLLoaderPtr transferrable_loader,
    const GURL& original_url) {
  DCHECK_CURRENTLY_ON(content::BrowserThread::UI);

  content::WebContents* web_contents = nullptr;
  if (frame_tree_node_id != content::RenderFrameHost::kNoFrameTreeNodeId) {
    web_contents =
        content::WebContents::FromFrameTreeNodeId(frame_tree_node_id);
  } else {
    web_contents = content::WebContents::FromRenderFrameHost(
        content::RenderFrameHost::FromID(render_process_id, render_frame_id));
  }
  if (!web_contents)
    return;

#if !defined(TOOLKIT_QT)
  // If the request was for NoStatePrefetch, abort the prefetcher and do not
  // continue. This is because plugins cancel NoStatePrefetch, see
  // http://crbug.com/343590.
  prerender::NoStatePrefetchContents* no_state_prefetch_contents =
      prerender::ChromeNoStatePrefetchContentsDelegate::FromWebContents(
          web_contents);
  if (no_state_prefetch_contents) {
    no_state_prefetch_contents->Destroy(prerender::FINAL_STATUS_DOWNLOAD);
    return;
  }
#endif // !defined(TOOLKIT_QT)

  auto* browser_context = web_contents->GetBrowserContext();

  const Extension* extension = ExtensionRegistry::Get(browser_context)
                                   ->enabled_extensions()
                                   .GetByID(extension_id);
  if (!extension)
    return;

  MimeTypesHandler* handler = MimeTypesHandler::GetHandler(extension);
  if (!handler->HasPlugin())
    return;

  // If the mime handler uses MimeHandlerViewGuest, the MimeHandlerViewGuest
  // will take ownership of the stream.
  GURL handler_url(Extension::GetBaseURLFromExtensionId(extension_id).spec() +
                   handler->handler_url());

  // If this is an inner contents, then (a) it's a guest view and doesn't have a
  // tab id anyway, or (b) it's a portal. In the portal case, providing a
  // distinct tab id breaks the pdf viewer / extension APIs. For now we just
  // indicate that a portal contents has no tab id. Unfortunately, this will
  // still be broken in subtle ways once the portal is activated (e.g. some
  // forms of zooming won't work).
  // TODO(1042323): Present a coherent representation of a tab id for portal
  // contents.
  int tab_id = web_contents->GetOuterWebContents()
                   ? SessionID::InvalidValue().id()
#if !defined(TOOLKIT_QT)
                   : ExtensionTabUtil::GetTabId(web_contents);
#else
                   : -1;
#endif // !defined(TOOLKIT_QT)

  std::unique_ptr<StreamContainer> stream_container(
      new StreamContainer(tab_id, embedded, handler_url, extension_id,
                          std::move(transferrable_loader), original_url));
  MimeHandlerStreamManager::Get(browser_context)
      ->AddStream(view_id, std::move(stream_container), frame_tree_node_id,
                  render_process_id, render_frame_id);
}

}  // namespace extensions

==> qtwebengine-everywhere-src-6.8.3.zip: qtwebengine-everywhere-src-6.8.3/src/3rdparty/chromium/chrome/browser/extensions/api/streams_private/streams_private_api.cc <==
// Copyright 2012 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "chrome/browser/extensions/api/streams_private/streams_private_api.h"

#include <utility>

#if !BUILDFLAG(IS_QTWEBENGINE)
#include "chrome/browser/extensions/extension_tab_util.h"
#include "chrome/browser/preloading/prefetch/no_state_prefetch/chrome_no_state_prefetch_contents_delegate.h"
#include "components/no_state_prefetch/browser/no_state_prefetch_contents.h"
#endif // !BUILDFLAG(IS_QTWEBENGINE)
#include "components/sessions/core/session_id.h"
#include "content/public/browser/browser_thread.h"
#include "content/public/browser/render_frame_host.h"
#include "content/public/browser/web_contents.h"
#include "extensions/browser/extension_registry.h"
#include "extensions/browser/guest_view/mime_handler_view/mime_handler_stream_manager.h"
#include "extensions/browser/guest_view/mime_handler_view/mime_handler_view_guest.h"
#include "extensions/common/manifest_handlers/mime_types_handler.h"
#include "pdf/buildflags.h"

#if BUILDFLAG(ENABLE_PDF)
#include "base/feature_list.h"
#if !BUILDFLAG(IS_QTWEBENGINE)
#include "chrome/browser/pdf/pdf_viewer_stream_manager.h"
#endif // !BUILDFLAG(IS_QTWEBENGINE)
#include "extensions/common/constants.h"
#include "pdf/pdf_features.h"
#endif  // BUILDFLAG(ENABLE_PDF)

namespace extensions {

void StreamsPrivateAPI::SendExecuteMimeTypeHandlerEvent(
    const std::string& extension_id,
    const std::string& stream_id,
    bool embedded,
    int frame_tree_node_id,
    blink::mojom::TransferrableURLLoaderPtr transferrable_loader,
    const GURL& original_url,
    const std::string& internal_id) {
  DCHECK_CURRENTLY_ON(content::BrowserThread::UI);

  content::WebContents* web_contents =
      content::WebContents::FromFrameTreeNodeId(frame_tree_node_id);
  if (!web_contents)
    return;

#if !BUILDFLAG(IS_QTWEBENGINE)
  // If the request was for NoStatePrefetch, abort the prefetcher and do not
  // continue. This is because plugins cancel NoStatePrefetch, see
  // http://crbug.com/343590.
  prerender::NoStatePrefetchContents* no_state_prefetch_contents =
      prerender::ChromeNoStatePrefetchContentsDelegate::FromWebContents(
          web_contents);
  if (no_state_prefetch_contents) {
    no_state_prefetch_contents->Destroy(prerender::FINAL_STATUS_DOWNLOAD);
    return;
  }
#endif // !BUILDFLAG(IS_QTWEBENGINE)

  auto* browser_context = web_contents->GetBrowserContext();

  const Extension* extension = ExtensionRegistry::Get(browser_context)
                                   ->enabled_extensions()
                                   .GetByID(extension_id);
  if (!extension)
    return;

  MimeTypesHandler* handler = MimeTypesHandler::GetHandler(extension);
  if (!handler->HasPlugin())
    return;

  // If the mime handler uses MimeHandlerViewGuest, the MimeHandlerViewGuest
  // will take ownership of the stream.
  GURL handler_url(Extension::GetBaseURLFromExtensionId(extension_id).spec() +
                   handler->handler_url());

  // If this is an inner contents, then (a) it's a guest view and doesn't have a
  // tab id anyway, or (b) it's a portal. In the portal case, providing a
  // distinct tab id breaks the pdf viewer / extension APIs. For now we just
  // indicate that a portal contents has no tab id. Unfortunately, this will
  // still be broken in subtle ways once the portal is activated (e.g. some
  // forms of zooming won't work).
  // TODO(1042323): Present a coherent representation of a tab id for portal
  // contents.
  int tab_id = web_contents->GetOuterWebContents()
                   ? SessionID::InvalidValue().id()
#if !BUILDFLAG(IS_QTWEBENGINE)
                   : ExtensionTabUtil::GetTabId(web_contents);
#else
                   : -1;
#endif // !BUILDFLAG(IS_QTWEBENGINE)

  std::unique_ptr<StreamContainer> stream_container(
      new StreamContainer(tab_id, embedded, handler_url, extension_id,
                          std::move(transferrable_loader), original_url));

#if BUILDFLAG(ENABLE_PDF) && !BUILDFLAG(IS_QTWEBENGINE)
  if (base::FeatureList::IsEnabled(chrome_pdf::features::kPdfOopif) &&
      extension_id == extension_misc::kPdfExtensionId) {
    pdf::PdfViewerStreamManager::CreateForWebContents(web_contents);
    pdf::PdfViewerStreamManager::FromWebContents(web_contents)
        ->AddStreamContainer(frame_tree_node_id, internal_id,
                             std::move(stream_container));
    return;
  }
#endif  // BUILDFLAG(ENABLE_PDF) && !BUILDFLAG(IS_QTWEBENGINE)

  MimeHandlerStreamManager::Get(browser_context)
      ->AddStream(stream_id, std::move(stream_container), frame_tree_node_id);
}

}  // namespace extensions
